<h1 align="center">
<sub>
    <img src=".github/assets/jishaku_logo.svg" height="36">
</sub>
synthhaku - jishaku fork for disnake
</h1>
<p align="center">
<sup>
a debugging and utility extension for disnake bots
</sup>
synthhaku is an extension for bot developers that enables rapid prototyping, experimentation, and debugging of features for bots.

One of synthhaku's core philosophies is to be dynamic and easy-to-use. Here's the two step install:

> 1. Download synthhaku on the command line using pip:
> ```bash
> pip install -U synthhaku
> ```
> 2. Load the extension in your bot code before it runs:
> ```python
> bot.load_extension('synthhaku')
> ```
> That's it!

You can also import the module to use the command development utilities.

## Links:
- [Discord](https://discord.gg/z7YUcUMA9m)
- [GitHub](https://github.com/Synth-discord-bot/synth-haku)
- [PyPI](https://pypi.org/project/synthhaku)
